命令行:

```
kk

参数:
    -port=8000   端口号，若不传入则从8000起遍历一个可用端口
    -path=.      显示目录，默认为当前目录
    -dev=True    开发者模式，默认为True
    -all=False   是否显示隐藏文件，默认为False
```

在显示的文件列表标题上，点击“一般模式”将切换是否直接显示图片/视频/音乐。

在面包屑导航点击文件名上可以快速跳转到目标位置。

在面包屑导航左侧可以切换是否显示导航树。

注意：

    如果目录下有非常多的文件，显示目录树可能会耗时较长时间，关闭后则不会显示。
    如果dev=False，可能导致文件在浏览器上有缓存，需要强制刷新。

默认支持的URL参数:

    w=256:  将图片等比例缩放到固定宽度
    h=256:  将图片等比例缩放到固定高度，w和h同时存在时则缩放到指定宽高
    f=json: 以json格式显示数据

首次启动后会在后台进行一次全量扫描，之后每小时进行一次全量扫描，更新文件目录缓存。

如果一个文件夹下有大量文件，这将提高显示速度，可以防止首次遍历耗时太久。

支持.json, .yml, .yaml, .jpg, .jpeg, .bmp, .png, .mp3, .mp4, .ogg, .pdf, .txt, .md, .py, .sh, .h, .c, .cpp, .js, .css, .html, .java, .go, .ini, .ipynb等文件直接预览，支持代码高亮，支持文件搜索。


支持文件夹压缩及压缩包解压，其他类型的文件则直接下载，可以删除文件或复制文件链接。

其他功能:

支持表格和统计图表显示，需要先安装mongodb用于数据存储。

截图:

![](https://ww1.sinaimg.cn/large/005YhI8igy1fvjd3y37wfj31ay0y6dji)
